referrerpolicy=no-referrer-when-downgrade

Function accept_curator

pub fn accept_curator<T: Config<I>, I: 'static>(
    parent_bounty_id: BountyIndex,
    child_bounty_id: Option<BountyIndex>,
)
Accept the curator role for a child-/bounty.

Dispatch Origin

Must be signed by the proposed curator.

Details

  • The child-/bounty must be in the Funded state.
  • The curator must accept the role by calling this function.
  • A deposit will be reserved from the curator and refunded upon successful payout.

Parameters

  • parent_bounty_id: Index of parent bounty.
  • child_bounty_id: Index of child-bounty.

Events

Emits Event::BountyBecameActive if successful.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::accept_curator.