referrerpolicy=no-referrer-when-downgrade

Function award_bounty

pub fn award_bounty<T: Config<I>, I: 'static>(
    parent_bounty_id: BountyIndex,
    child_bounty_id: Option<BountyIndex>,
    beneficiary: BeneficiaryLookupOf<T, I>,
)
Awards the child-/bounty to a beneficiary account/location, initiating the payout payments to both the beneficiary and the curator.

Dispatch Origin

This function can only be called by the RejectOrigin or the child-/bounty curator.

Details

  • The child-/bounty must be in the Active state.
  • if awarding a parent bounty it must not have active or funded child bounties.
  • Initiates payout payment from the child-/bounty to the beneficiary account/location.
  • If successful the child-/bounty status is updated to PayoutAttempted.
  • In case of a payout failure, the child-/bounty status must be updated with check_status call before retrying with retry_payment call.

Parameters

  • parent_bounty_id: Index of parent bounty.
  • child_bounty_id: Index of child-bounty.
  • beneficiary: Account/location to be awarded the child-/bounty.

Events

Emits Event::BountyAwarded and Event::Paid if successful.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::award_bounty.