referrerpolicy=no-referrer-when-downgrade

Function fund_child_bounty

pub fn fund_child_bounty<T: Config<I>, I: 'static>(
    parent_bounty_id: BountyIndex,
    value: T::Balance,
    metadata: T::Hash,
    curator: Option<AccountIdLookupOf<T>>,
)
Fund a new child-bounty with a proposed curator, initiating the payment from the parent bounty to the child-bounty account/location.

Dispatch Origin

Must be signed by the parent curator.

Details

  • If curator is not provided, the child-bounty will default to using the parent curator, allowing the parent curator to immediately call check_status and award_bounty to payout the child-bounty.
  • In case of a funding failure, the child-/bounty status must be updated with the check_status call before retrying with retry_payment call.

Parameters

  • parent_bounty_id: Index of parent bounty for which child-bounty is being added.
  • value: The payment amount of this child-bounty.
  • metadata: The hash of an on-chain stored preimage with child-bounty metadata.
  • curator: Address of child-bounty curator.

Events

Emits Event::ChildBountyCreated and Event::Paid if successful.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::fund_child_bounty.