pub fn check_status<T: Config<I>, I: 'static>(
parent_bounty_id: BountyIndex,
child_bounty_id: Option<BountyIndex>,
)Expand description
Check and update the payment status of a child-/bounty.
Dispatch Origin
Must be signed.
Details
- If the child-/bounty status is
FundingAttempted, it checks if the funding payment has succeeded. If successful, the bounty status becomesFunded. - If the child-/bounty status is
RefundAttempted, it checks if the refund payment has succeeded. If successful, the child-/bounty is removed from storage. - If the child-/bounty status is
PayoutAttempted, it checks if the payout payment has succeeded. If successful, the child-/bounty is removed from storage.
Parameters
parent_bounty_id: Index of parent bounty.child_bounty_id: Index of child-bounty.
Events
Emits Event::BountyBecameActive if the child/bounty status transitions to Active.
Emits Event::BountyRefundProcessed if the refund payment has succeed.
Emits Event::BountyPayoutProcessed if the payout payment has succeed.
Emits Event::PaymentFailed if the funding, refund our payment payment has failed.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::check_status.