pub fn fund_child_bounty<T: Config<I>, I: 'static>(
parent_bounty_id: BountyIndex,
value: T::Balance,
metadata: T::Hash,
curator: Option<AccountIdLookupOf<T>>,
)Expand description
Fund a new child-bounty with a proposed curator, initiating the payment from the parent bounty to the child-bounty account/location.
Dispatch Origin
Must be signed by the parent curator.
Details
- If
curatoris not provided, the child-bounty will default to using the parent curator, allowing the parent curator to immediately callcheck_statusandaward_bountyto payout the child-bounty. - In case of a funding failure, the child-/bounty status must be updated with the
check_statuscall before retrying withretry_paymentcall.
Parameters
parent_bounty_id: Index of parent bounty for which child-bounty is being added.value: The payment amount of this child-bounty.metadata: The hash of an on-chain stored preimage with child-bounty metadata.curator: Address of child-bounty curator.
Events
Emits Event::ChildBountyCreated and Event::Paid if successful.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::fund_child_bounty.