pub fn propose_curator<T: Config<I>, I: 'static>(
parent_bounty_id: BountyIndex,
child_bounty_id: Option<BountyIndex>,
curator: AccountIdLookupOf<T>,
)Expand description
Propose a new curator for a child-/bounty after the previous was unassigned.
Dispatch Origin
Must be signed by T::SpendOrigin for a bounty, or by the parent bounty curator
for a child-bounty.
Details
- The child-/bounty must be in the
CuratorUnassignedstate. - For a bounty, the
SpendOriginmust have sufficient permissions to propose the curator.
Parameters
parent_bounty_id: Index of bounty.child_bounty_id: Index of child-bounty.curator: Account to be proposed as the curator.
Events
Emits Event::CuratorProposed if successful.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::propose_curator.