pub fn retry_payment<T: Config<I>, I: 'static>(
parent_bounty_id: BountyIndex,
child_bounty_id: Option<BountyIndex>,
)Expand description
Retry the funding, refund or payout payments.
Dispatch Origin
Must be signed.
Details
- If the child-/bounty status is
FundingAttempted, it retries the funding payment from funding source the child-/bounty account/location. - If the child-/bounty status is
RefundAttempted, it retries the refund payment from the child-/bounty account/location to the funding source. - If the child-/bounty status is
PayoutAttempted, it retries the payout payment from the child-/bounty account/location to the beneficiary account/location.
Parameters
parent_bounty_id: Index of parent bounty.child_bounty_id: Index of child-bounty.
Events
Emits Event::Paid if the funding, refund or payout payment has initiated.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::retry_payment.