pub fn unassign_curator<T: Config<I>, I: 'static>(
parent_bounty_id: BountyIndex,
child_bounty_id: Option<BountyIndex>,
)Expand description
Unassign curator from a child-/bounty.
Dispatch Origin
This function can only be called by the RejectOrigin or the child-/bounty curator.
Details
- If this function is called by the
RejectOrigin, or by the parent curator in the case of a child bounty, we assume that the curator is malicious or inactive. As a result, we will slash the curator when possible. - If the origin is the child-/bounty curator, we take this as a sign they are unable to do their job and they willingly give up. We could slash them, but for now we allow them to recover their deposit and exit without issue. (We may want to change this if it is abused).
- If successful, the child-/bounty status is updated to
CuratorUnassigned. To reactivate the bounty, a new curator must be proposed and must accept the role.
Parameters
parent_bounty_id: Index of parent bounty.child_bounty_id: Index of child-bounty.
Events
Emits Event::CuratorUnassigned if successful.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::unassign_curator.